@@ -6,12 +6,14 @@ LSmeans <- function(object, effect=NULL, at=NULL, level=0.95,...){
 
 LSmeans.default <- function(object, effect=NULL, at=NULL, level=0.95,...){
     K      <- .getK(object, effect=effect, at=at)
-    linest(object, K, level=level, ...)
+    out <- linest(object, K, level=level, ...)
+    out
 }
 
 LSmeans.lmerMod <- function(object, effect=NULL, at=NULL, level=0.95, adjust.df=TRUE, ...){
     K      <- .getK(object, effect=effect, at=at)
-    linest(object, K, level=level, adjust.df=adjust.df, ...)
+    out <- linest(object, K, level=level, adjust.df=adjust.df, ...)
+    out
 }
 
 popMeans <- LSmeans
